@@ -3,7 +3,7 @@ use crypto_rest_client::{fetch_l2_snapshot, BinanceOptionRestClient};
 
 #[test]
 fn test_agg_trades() {
-    let text = BinanceOptionRestClient::fetch_trades("BTC-220304-38000-P", None).unwrap();
+    let text = BinanceOptionRestClient::fetch_trades("BTC-220429-50000-C", None).unwrap();
     assert!(text.starts_with("{"));
 }
 
@@ -12,7 +12,7 @@ fn test_l2_snapshot() {
     let text = fetch_l2_snapshot(
         "binance",
         MarketType::EuropeanOption,
-        "BTC-220304-38000-P",
+        "BTC-220429-50000-C",
         Some(3),
     )
     .unwrap();
